@@ -7,8 +7,8 @@ test_that("Download speeds are as expected", {
     list("movebank:move2_user" = Sys.getenv("MBPWD")),
     withr::with_options(list(keyring_backend = "env"), {
       show_failure(expect_lt(system.time(
-        suppressMessages(aa <- movebank_download_study(1259686571, timestamp_end = "2023-1-1", attributes = "all"))
-      )["elapsed"], 78))
+        suppressMessages(aa <- movebank_download_study(1259686571L, timestamp_end = "2023-1-1", attributes = "all"))
+      )["elapsed"], 78L))
       expect_true(all(c(
         "taxon_canonical_name", "tag_id", "individual_id",
         "deployment_id", "study_id"
@@ -18,7 +18,12 @@ test_that("Download speeds are as expected", {
         "tag_id", "individual_id", "study_id", "deployment_id"
       ) %in% colnames(aa)))
 
-      show_failure(expect_lt(system.time(a <- movebank_download_study(2911040, attributes = NULL))["elapsed"], 9))
+      show_failure(expect_lt(
+        system.time(
+          a <- movebank_download_study(2911040L, attributes = NULL)
+        )["elapsed"],
+        9.0
+      ))
       expect_identical(a |> mt_time() |> lubridate::tz(), "UTC")
       expect_true(all(c(
         "taxon_canonical_name", "tag_id", "individual_id",
@@ -31,7 +36,7 @@ test_that("Download speeds are as expected", {
       ) %in% colnames(a)))
       show_failure(expect_lt(system.time(
         movebank_retrieve(entity_type = "study", license_type = "CC_0")
-      )["elapsed"], 2))
+      )["elapsed"], 2.0))
     })
   )
 })
@@ -43,10 +48,12 @@ test_that("Download speeds for deployment", {
   withr::with_envvar(
     list("movebank:move2_user" = Sys.getenv("MBPWD")),
     withr::with_options(list(keyring_backend = "env"), {
-      show_failure(expect_lt((a <- system.time(movebank_download_deployment(1259686571)))["elapsed"], 4))
-      expect_lt(summary(a)["system"], .5)
-      show_failure(expect_lt((b <- system.time(movebank_download_deployment(2911040)))["elapsed"], 4))
-      expect_lt(summary(b)["system"], .5)
+      show_failure(expect_lt((
+        a <- system.time(movebank_download_deployment(1259686571L)))["elapsed"], 4.0))
+      expect_lt(summary(a)["system"], 0.5)
+      show_failure(expect_lt((
+        b <- system.time(movebank_download_deployment(2911040L)))["elapsed"], 4.0))
+      expect_lt(summary(b)["system"], 0.5)
     })
   )
 })
